---
title: Zalajmkwély
lang: zalajmkwely
...

# Phonology

## Vowels

                 Front                 Back
--------- --------------------- ---------------------
     High    `/i ɪ/` `{y i}`       `/u ʊ/` `{ů u}`
 Mid-high      `/e/` `{é}`         `/o õ/` `{ó ų}`
  Mid-low    `/ɛ ɛ̃/` `{e į}`         `/ɔ/` `{o}`
      Low    `/a æ̃/` `{ä ę}`       `/ɑ ɒ̃/` `{a ą}`

Words have vowel harmony in non-nasal vowels between "tense" and "lax". If a
root contains only nasal vowels, then the harmony defaults to lax. In affixes,
a vowel that alternates depending on harmony (which is all of them, other than
nasals) is indicated with a capital letter. The realisation of these vowels is
based on the root nearest to the affix.

        `{I}`   `{U}`   `{E}`   `{O}`   `{A}`
------ ------- ------- ------- ------- -------
 Tense  `{y}`   `{ů}`   `{é}`   `{ó}`   `{ä}`
 Lax    `{i}`   `{u}`   `{e}`   `{o}`   `{a}`

Before a consonant, nasal vowels can be written as a vowel followed by
`{m}`/`{n}`/`{ŋ}`. In this case, `{on}`, `{ón}`, etc, are pronounced
`/ɒ̃/` like `{ą}`.

### Allophony

- Vowels are slightly longer when stressed.
- `/ɛ e/` are lowered to `/æ/` before a velar (including `[ɫ]`).
- A `[ʔ]` is inserted into word boundaries with a vowel on both sides.


## Consonants

                 Labial            Dental            Dorsal
---------- ----------------- ----------------- -----------------
   Plosive  `/p b/` `{p b}`   `/t d/` `{t d}`     `/k/` `{k}`
 Fricative    `/f/` `{f}`     `/s z/` `{s z}`   `/x ʁ/` `{h ř}`
     Nasal    `/m/` `{m}`       `/n/` `{n}`       `/ŋ/` `{g}`
     Other    `/w/` `{w}`     `/l ɾ/` `{l r}`     `/j/` `{j}`

The word "glide" refers to `/w j/`, and "liquid" to `/l ɾ ʁ/`.

The sequence `/ŋŋ/` is written `{ng}` (and pronounced `[ŋɡ]`).

### Allophony

- `/l/` is `[ɫ]` anywhere except before one of `/j i/`.
- `/p t k/` are affricated to `[pf ts kx]` directly before a stressed vowel,
  and to `[pf tʃ kx]` at the end of a word.
- `/x/` is pronounced `[χ]` at the end of a word or after a lax vowel.
- `/b d/` become `[v ð]` word finally if immediately preceded by a vowel.
- `/ŋ/` becomes `[ɡ]` after another `/ŋ/`, before `/z/` or `/d/`, or when not next to a
  vowel.
- `/s z/` become `[ʃ ʒ]` at the end of a word or before a plosive (including the
  `[ɡ]` coming from `/ŋ/`).
- `/d/` becomes `[dʒ]` at the end of a word if _not_ directly preceded by a
  vowel.
- `/t d s z/` become `[tʃ dʒ ʃ ʒ]` before one of `/j i e/`. The `/j/` is then
  dropped if there was one.


## Syllable structure

In [EBNF]:

[EBNF]: //en.wikipedia.org/wiki/Extended_Backus-Naur_form

```ebnf
word = [init cons], nucleus, {inner cons, nucleus}, [final cons];
nucleus = (?vowel?, ?glide?) - ('ɪj' | 'ij' | 'ɛ̃j' | 'ʊw' | 'uw' | 'õw');
init cons = ?consonant?, [?glide?]
          | ('p' | 't' | 'k'), 's', [?glide?]
          | ('b' | 'd' | 'ŋ'), 'z', [?glide?]
          | (?consonant? - ?liquid?), ?liquid?
          | ('mb' | 'nd' | 'ŋŋ'), [?glide?];
inner cons = '·', ?consonant?
           | '·', (?consonant? - ?glide?), ?glide?
           | (('p' | 'k'), '·', ('t' | 's') | ('b' | 'ŋ'), '·', ('d' | 'z')),
             (* the above ŋ is aksdm *)
           | ('s', '·', ('p' | 't' | 'k') | 'z', '·', ('b' | 'd' | 'm' | 'n' | 'ŋ'))
           | ('f' | 'h'), '·', ?voiceless plosive?
           | ?liquid?, '·', ?nasal?
           | ('m · m' | 'n · n' | 'ŋ · ŋ');
final cons = ?consonant? - (?glide? | ?nasal?), ['s']
           | ?liquid?, (?consonant? - (?glide? | ?liquid? | 'n' | 'ŋ')), ['s'];
```

The `{·}` in [inner cons]{.ebnf-nt} indicates where the syllable boundary is.


## Stress

Stress falls on the last syllable of the stem. (In a compound word, the last
syllable of the last stem.) Inflectional endings do not cause it to move.

- `{kwély}` 'language' `/kweˈliː/`
- `{kwélyjäm}` 'language.`!GEN!`' `/kweˈliː.jam/`



# Verbs

Verbs do not inflect themselves, but the conjugation is reflected on a highly
fused particle following the main verb. This particle inflects for person,
gender (in the third person), number, tense, and a distinction between
perfective/imperfective. The ‘citation form’ of this particle is `{as}`, the
`!1SG!`;`!PRS!`;`!IMP!` form. The `!3X!` form is used with a group of
people/objects of multiple genders, as well as for unknown or indefinite
referents (whether singular or plural), and impersonal sentences such as
instructions on signs.

## Present

:::twocol

- `{řazgų kéd as}` 'I am eating bread'
- `{plas énlä}` 'He sneezes'

:::


         `!IMPF SG!`    `!PL!`    `!PF SG!`    `!PL!`
------- ------------- ---------- ----------- ----------
  `!1!`     `{as}`      `{az}`      `{és}`     `{ez}`
  `!2!`     `{ad}`      `{am}`      `{ed}`     `{ém}`
 `!3A!`    `{äly}`     `{alis}`    `{énly}`   `{elis}`
 `!3B!`    `{älä}`     `{älůs}`    `{énlä}`   `{élůs}`
 `!3C!`    `{äló}`     `{alos}`    `{énló}`   `{elos}`
 `!3X!`       —        `{älós}`       —       `{élós}`


## Past

:::twocol

- `{řazgų kéd als}` 'I was eating bread'
- `{řazgų kéd éls}` 'I ate bread'

:::


         `!IMPF SG!`     `!PL!`    `!PF SG!`     `!PL!`
------- ------------- ----------- ----------- -----------
  `!1!`    `{als}`      `{ajz}`     `{éls}`     `{eliz}`
  `!2!`    `{ajd}`      `{alm}`     `{elid}`    `{élym}`
 `!3B!`    `{äjlä}`    `{äjlůs}`    `{éllä}`    `{élůs}`
 `!3A!`    `{äjly}`    `{ajlis}`    `{élly}`   `{ellis}`
 `!3C!`    `{äjló}`    `{ajlos}`    `{élló}`   `{ellos}`
 `!3X!`       —        `{äjlós}`       —       `{éllós}`


## Future

:::twocol

- `{řazgų kéd ojs}` 'I will be eating bread'
- `{řazgų kéd éws}` 'I will eat bread'

:::

         `!IMPF SG!`     `!PL!`    `!PF SG!`     `!PL!`
------- ------------- ----------- ----------- -----------
  `!1!`    `{ojs}`      `{wįz}`     `{ews}`     `{jųz}`
  `!2!`    `{wįd}`      `{ólm}`     `{jųd}`     `{ewm}`
 `!3B!`    `{ójlä}`    `{ójlůs}`    `{éwlä}`   `{éwlůs}`
 `!3A!`    `{ójly}`    `{ojlis}`    `{éwly}`   `{ewlis}`
 `!3C!`    `{ójló}`    `{ojlos}`    `{éwló}`   `{ewlos}`
 `!3X!`       —        `{ójlós}`       —       `{éwlós}`

Questions, either of the yes/no or of the content kind, are indicated by a
particle `{ům}` (which is also the verb 'to ask') appearing after the inflection
of `{as}`.

Other aspects and moods are indicated with auxiliary verbs.

:::glosses

- Bolus hawa můtä jas jųz.
- [bɔˈlʊʃ xɑˈwɑ muˈta jɑʃ jõʒ]
- bolus    hawa můtä  jas jųz
- tomorrow can  start go  1PL;FUT;PRF
- We can set off tomorrow.

---

- Pulų jafų ep äly ům?
- [pʊˈlõ jaˈfõ epf alijˈõ]
- pu-lų jaf-ų ep äly ům
- what-ACC name-ACC have 2SG;PRS;IMP QU
- What is your name?

:::


# Nouns & adjectives


## Case

Nouns have five cases: nominative, accusative, genitive, dative, and locative.
The last of these is used only with preposition-type words. As a result of the
inflectional suffixes, nouns almost always end in a consonant. The only
exception is words ending in `/ɪ/` or `/i/`, which gain an extra `/j/` before
the suffixes. The spelling similarly gains a `{–j}`.

Nouns are divided into a few classes. Each class requires the use of a specific
inflection class of `{as}`, labelled `!A!`, `!B!`, or `!C!`. The conventional
labels for the classes are:

I.    Sapient `!(A)!` sapients
II.   Water `!(B)!` bodies of water, and the sky
III.  Ground `!(A)!` the ground, rocks, metals, chemical elements
IV.   Artifice `!(C)!` handheld tools, small plastic items, electronics
V.    Spiritual `!(C)!` gods, the mind & soul, large natural events, language
VI.   Containers `!(B)!` boxes, pans, bowls, wardrobes, etc;
      beds, chairs, and other furniture for sitting or lying on
VII.  Clothing `!(B)!` clothing and carried objects like umbrellas and bags
VIII. Food `!(C)!` food and drink
IX.   Animal `!(B)!` animals (including mythical creatures)

(**TODO** zk names for genders)

Not all nouns fall into the class which the labels would suggest, and if none of
the labels fit then the choice is arbitrary. (As is usual with `!NOM!`–`!ACC!`
languages, `!NOM!`;`!SG!` is the citation form in dictionaries.) People's names
are assigned to whichever class they choose.

                        `!I!`         `!II!`        `!III!`       `!IV!`        `!V!`        `!VI!`       `!VII!`       `!VIII!`       `!IX!`
--------- -------- -------------- -------------- ------------- ------------ ------------ ------------- ------------- ------------- -------------
                       'woman'        'lake'         'iron'       'tool'       'life'        'cup'         'shoe'       'bread'        'dog'
 `!NOM!`   `!SG!`     `{fälés}`      `{dusal}`      `{klůp}`      `{řas}`      `{kól}`      `{mbuz}`      `{gřub}`      `{řazg}`      `{kląs}`
           `!PL!`    `{fälésé}`     `{dusala}`     `{klůpä}`     `{řasa}`     `{kólä}`     `{mbuze}`     `{gřube}`     `{řazgį}`     `{kląse}`
 `!ACC!`   `!SG!`    `{fälésų}`     `{dusalų}`     `{klůpů}`     `{řasol}`    `{kólų}`     `{mbuzol}`    `{gřubę}`     `{řazgų}`     `{kląsų}`
           `!PL!`    `{fälésów}`    `{dusaloh}`    `{klůpůf}`    `{řasuf}`    `{kólůh}`    `{mbuzuf}`    `{gřubęw}`    `{řazgoh}`    `{kląsow}`
 `!GEN!`   `!SG!`    `{fälésäm}`    `{dusalam}`    `{klůpym}`    `{řasim}`    `{kóläm}`    `{mbuzat}`    `{gřubam}`    `{řazgim}`    `{kląsam}`
           `!PL!`    `{fälésäz}`    `{dusalat}`    `{klůpyt}`    `{řasit}`    `{kóläz}`    `{mbuzaz}`    `{gřubat}`    `{řazgįz}`    `{kląsaz}`
 `!DAT!`   `!SG!`    `{fälésój}`    `{dusale}`     `{klůpój}`    `{řasoj}`    `{kólé}`     `{mbuze}`     `{gřuboj}`    `{řazgai}`    `{kląsi}`
           `!PL!`    `{fälésůd}`    `{dusaloj}`    `{klůpůd}`    `{řasud}`    `{kólój}`    `{mbuzoj}`    `{gřubud}`    `{řazged}`    `{kląsid}`
 `!LOC!`   `!SG!`    `{fälésés}`    `{dusales}`    `{klůpés}`    `{řases}`    `{kólés}`    `{mbuzes}`    `{gřubes}`    `{řazges}`    `{kląses}`
           `!PL!`   `{fälésęts}`   `{dusalęts}`   `{klůpęts}`   `{řasęts}`   `{kólęts}`   `{mbuzęts}`   `{gřubęts}`   `{řazgęts}`   `{kląsęts}`

Adjectives, including genitive nouns, agree in case with their head noun, but not number. Adjectives, except for possessive pronouns, attached to a genitive noun agree with that noun's head, but not with the genitive noun itself.

:::twocol

- `!NOM!`: `{bym}` 'good'
- `!ACC!`: `{bymů}`
- `!DAT!`: `{bymó}`
- `!LOC!`: `{bymés}`

:::


# Pronouns

__TODO__

## Case

|           | `!NOM!` |  `!ACC!` |  `!GEN!` |  `!DAT!` | `!LOC!` |
|----------:|:-------:|:--------:|:--------:|:--------:|:-------:|
|   `!1SG!` |  `{yn}` |  `{iwn}` |  `{ym}`  |  `{ém}`  | `{yné}` |
|   `!1PL!` |  `{fę}` |  `{fęw}` | `{fénó}` | `{fejm}` | `{fęj}` |
|   `!2SG!` |  `{ol}` |  `{ow}`  |   `{ů}`  |  `{wą}`  | `{wój}` |
|   `!2PL!` | `{zůl}` |  `{zow}` |  `{zów}` |  `{zům}` | `{zůj}` |
| `!3SG.A!` | `{sem}` |  `{sju}` |  `{só}`  |  `{sem}` | `{sęs}` |
| `!3SG.B!` | `{lem}` |  `{lew}` |  `{ló}`  |  `{lem}` | `{lęs}` |
| `!3SG.C!` |  `{em}` |   `{ä}`  |  `{aw}`  |  `{äm}`  |  `{ęs}` |
| `!3PL.A!` | `{gej}` |  `{gęw}` |  `{déw}` |  `{gim}` | `{gįs}` |
| `!3PL.B!` | `{gaj}` |  `{gąw}` |  `{djó}` |  `{gam}` | `{gąs}` |
| `!3PL.C!` |  `{gó}` |  `{gů}`  |  `{gů}`  |  `{gam}` | `{gąs}` |
| `!3PL.X!` | `{gew}` | `{gejų}` |  `{déw}` |  `{gam}` | `{gąs}` |

# Syntax

## Questions

To form a yes/no question, the particle `{ům}` is added to the end of the
sentence. When used in this way, `{ům}` is pronounced as an `{ų}` attached to
the final word.

:::glosses

- Bymů bälsůh ep ad ům?
- [biˈmuː baɫˈsuːχ ɛpf ɑˈdõ]
- bym-ů    bäls-ůh     ep   ad           ům
- good-ACC mood-ACC;PL have 2SG;PRS;IMPF QU
- Are you feeling good?

:::

To answer a question, conjugate `{as}` appropriately, and follow with `{řab}`
for agreement and `{zol}` for disagreement. In formal circumstances the main
verb stem may be echoed before the `{as}`. Before `{zol}`, a `{s}` or `{z}` at
the end of the form of `{as}` is dropped.

:::glosses

- As řab.
- [ɑʃ ʁɑv]
- as           řab
- 1SG;PRS;IMPF CONFIRM
- Yes, I am.

---

- A zol.
- [ɑ zɔɫ]
- a(s)         zol
- 1SG;PRS;IMPF DENY
- No, I am not.

:::
